@@ -1,8 +1,11 @@
 from django.contrib import admin
 
+from ..models.leprikonsite import LeprikonSite
 
+
+@admin.register(LeprikonSite)
 class LeprikonSiteAdmin(admin.ModelAdmin):
-    list_display    = ('name',)
+    list_display = ('name',)
     filter_horizontal = ('registration_agreements',)
 
     def has_add_permission(self, request):
@@ -16,9 +19,3 @@ class LeprikonSiteAdmin(admin.ModelAdmin):
         if 'delete_selected' in actions:
             del(actions['delete_selected'])
         return actions
-
-    def get_fields(self, request, obj=None):
-        fields = super(LeprikonSiteAdmin, self).get_fields(request, obj)
-        if not obj or not obj.old_registration_agreement:
-            fields.remove('old_registration_agreement')
-        return fields
