@@ -2,7 +2,7 @@ from cms.cms_toolbars import ADMIN_MENU_IDENTIFIER
 from cms.toolbar.items import SubMenu
 from cms.toolbar_base import CMSToolbar
 from cms.toolbar_pool import toolbar_pool
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 
