@@ -10,11 +10,10 @@ https://docs.djangoproject.com/en/1.9/howto/deployment/wsgi/
 import os
 
 from django.core.wsgi import get_wsgi_application
-from raven.contrib.django.raven_compat.middleware.wsgi import Sentry
 
 os.environ.setdefault(
     "DJANGO_SETTINGS_MODULE",
     "{}.settings".format(os.environ.get('SITE_MODULE', 'leprikon.site')),
 )
 
-application = Sentry(get_wsgi_application())
+application = get_wsgi_application()
