@@ -1,6 +1,7 @@
 from ..models.courses import CourseRegistration
 from ..models.events import EventRegistration
 from ..models.leprikonsite import LeprikonSite
+from ..models.orderables import OrderableRegistration
 from .generic import TemplateView
 
 
@@ -19,4 +20,8 @@ class RegistrationsListView(TemplateView):
             subject__school_year=self.request.school_year,
             user=self.request.user,
         )
+        context['orderableregistrations'] = OrderableRegistration.objects.filter(
+            subject__school_year=self.request.school_year,
+            user=self.request.user,
+        )
         return context
