@@ -2,6 +2,7 @@ from cms.views import details as cms_view_details
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404, redirect
 from django.urls import reverse_lazy as reverse
+from django.utils.timezone import now
 from django.utils.translation import ugettext_lazy as _
 
 from ..forms.subjects import (
@@ -250,7 +251,8 @@ class SubjectRegistrationCancelView(UserRegistrationMixin, ConfirmUpdateView):
 
     def confirmed(self):
         if self.object.approved:
-            self.object.cancel_request = True
+            self.object.cancelation_requested = now()
+            self.object.cancelation_requested_by = self.request.user
             self.object.save()
         else:
             self.object.refuse()
